@@ -23,6 +23,6 @@ from pygls import IS_WIN
 unix_only = pytest.mark.skipif(IS_WIN, reason="Unix only")
 windows_only = pytest.mark.skipif(not IS_WIN, reason="Windows only")
 
-CMD_ASYNC = 'cmd_async'
-CMD_SYNC = 'cmd_sync'
-CMD_THREAD = 'cmd_thread'
+CMD_ASYNC = "cmd_async"
+CMD_SYNC = "cmd_sync"
+CMD_THREAD = "cmd_thread"
