@@ -38,8 +38,7 @@ class ConfiguredLS(ClientServer):
         @self.server.feature(
             TEXT_DOCUMENT_SEMANTIC_TOKENS_FULL_DELTA,
             SemanticTokensLegend(
-                token_types=["keyword", "operator"],
-                token_modifiers=["readonly"]
+                token_types=["keyword", "operator"], token_modifiers=["readonly"]
             ),
         )
         def f(
@@ -60,9 +59,7 @@ def test_capabilities(client_server):
         "keyword",
         "operator",
     ]
-    assert provider.legend.token_modifiers == [
-        "readonly"
-    ]
+    assert provider.legend.token_modifiers == ["readonly"]
 
 
 @ConfiguredLS.decorate()
@@ -71,8 +68,7 @@ def test_semantic_tokens_full_delta_return_tokens(client_server):
     response = client.lsp.send_request(
         TEXT_DOCUMENT_SEMANTIC_TOKENS_FULL_DELTA,
         SemanticTokensDeltaParams(
-            text_document=TextDocumentIdentifier(
-                uri="file://return.tokens"),
+            text_document=TextDocumentIdentifier(uri="file://return.tokens"),
             previous_result_id="id",
         ),
     ).result()
