@@ -30,10 +30,7 @@ from lsprotocol.types import (
 from ...conftest import ClientServer
 
 SemanticTokenReturnType = Optional[
-    Union[
-        SemanticTokensPartialResult,
-        Optional[SemanticTokens]
-    ]
+    Union[SemanticTokensPartialResult, Optional[SemanticTokens]]
 ]
 
 
@@ -44,8 +41,7 @@ class ConfiguredLS(ClientServer):
         @self.server.feature(
             TEXT_DOCUMENT_SEMANTIC_TOKENS_FULL,
             SemanticTokensLegend(
-                token_types=["keyword", "operator"],
-                token_modifiers=["readonly"]
+                token_types=["keyword", "operator"], token_modifiers=["readonly"]
             ),
         )
         def f(
@@ -66,9 +62,7 @@ def test_capabilities(client_server):
         "keyword",
         "operator",
     ]
-    assert provider.legend.token_modifiers == [
-        "readonly"
-    ]
+    assert provider.legend.token_modifiers == ["readonly"]
 
 
 @ConfiguredLS.decorate()
@@ -77,8 +71,7 @@ def test_semantic_tokens_full_return_tokens(client_server):
     response = client.lsp.send_request(
         TEXT_DOCUMENT_SEMANTIC_TOKENS_FULL,
         SemanticTokensParams(
-            text_document=TextDocumentIdentifier(
-                uri="file://return.tokens")
+            text_document=TextDocumentIdentifier(uri="file://return.tokens")
         ),
     ).result()
 
