@@ -17,8 +17,8 @@
 
 from typing import List, Optional
 
-from pygls.lsp.methods import DOCUMENT_HIGHLIGHT
-from pygls.lsp.types import (
+from lsprotocol.types import TEXT_DOCUMENT_DOCUMENT_HIGHLIGHT
+from lsprotocol.types import (
     DocumentHighlight,
     DocumentHighlightKind,
     DocumentHighlightOptions,
@@ -36,12 +36,10 @@ class ConfiguredLS(ClientServer):
         super().__init__()
 
         @self.server.feature(
-            DOCUMENT_HIGHLIGHT,
+            TEXT_DOCUMENT_DOCUMENT_HIGHLIGHT,
             DocumentHighlightOptions(),
         )
-        def f(
-            params: DocumentHighlightParams
-        ) -> Optional[List[DocumentHighlight]]:
+        def f(params: DocumentHighlightParams) -> Optional[List[DocumentHighlight]]:
             if params.text_document.uri == "file://return.list":
                 return [
                     DocumentHighlight(
@@ -74,7 +72,7 @@ def test_capabilities(client_server):
 def test_document_highlight_return_list(client_server):
     client, _ = client_server
     response = client.lsp.send_request(
-        DOCUMENT_HIGHLIGHT,
+        TEXT_DOCUMENT_DOCUMENT_HIGHLIGHT,
         DocumentHighlightParams(
             text_document=TextDocumentIdentifier(uri="file://return.list"),
             position=Position(line=0, character=0),
@@ -83,24 +81,24 @@ def test_document_highlight_return_list(client_server):
 
     assert response
 
-    assert response[0]["range"]["start"]["line"] == 0
-    assert response[0]["range"]["start"]["character"] == 0
-    assert response[0]["range"]["end"]["line"] == 1
-    assert response[0]["range"]["end"]["character"] == 1
-    assert "kind" not in response[0]
+    assert response[0].range.start.line == 0
+    assert response[0].range.start.character == 0
+    assert response[0].range.end.line == 1
+    assert response[0].range.end.character == 1
+    assert response[0].kind is None
 
-    assert response[1]["range"]["start"]["line"] == 1
-    assert response[1]["range"]["start"]["character"] == 1
-    assert response[1]["range"]["end"]["line"] == 2
-    assert response[1]["range"]["end"]["character"] == 2
-    assert response[1]["kind"] == DocumentHighlightKind.Write
+    assert response[1].range.start.line == 1
+    assert response[1].range.start.character == 1
+    assert response[1].range.end.line == 2
+    assert response[1].range.end.character == 2
+    assert response[1].kind == DocumentHighlightKind.Write
 
 
 @ConfiguredLS.decorate()
 def test_document_highlight_return_none(client_server):
     client, _ = client_server
     response = client.lsp.send_request(
-        DOCUMENT_HIGHLIGHT,
+        TEXT_DOCUMENT_DOCUMENT_HIGHLIGHT,
         DocumentHighlightParams(
             text_document=TextDocumentIdentifier(uri="file://return.none"),
             position=Position(line=0, character=0),
