@@ -17,8 +17,8 @@
 
 from typing import List, Optional
 
-from pygls.lsp.methods import DOCUMENT_LINK
-from pygls.lsp.types import (
+from lsprotocol.types import TEXT_DOCUMENT_DOCUMENT_LINK
+from lsprotocol.types import (
     DocumentLink,
     DocumentLinkOptions,
     DocumentLinkParams,
@@ -35,7 +35,7 @@ class ConfiguredLS(ClientServer):
         super().__init__()
 
         @self.server.feature(
-            DOCUMENT_LINK,
+            TEXT_DOCUMENT_DOCUMENT_LINK,
             DocumentLinkOptions(resolve_provider=True),
         )
         def f(params: DocumentLinkParams) -> Optional[List[DocumentLink]]:
@@ -68,7 +68,7 @@ def test_capabilities(client_server):
 def test_document_link_return_list(client_server):
     client, _ = client_server
     response = client.lsp.send_request(
-        DOCUMENT_LINK,
+        TEXT_DOCUMENT_DOCUMENT_LINK,
         DocumentLinkParams(
             text_document=TextDocumentIdentifier(uri="file://return.list"),
         ),
@@ -76,20 +76,20 @@ def test_document_link_return_list(client_server):
 
     assert response
 
-    assert response[0]["range"]["start"]["line"] == 0
-    assert response[0]["range"]["start"]["character"] == 0
-    assert response[0]["range"]["end"]["line"] == 1
-    assert response[0]["range"]["end"]["character"] == 1
-    assert response[0]["target"] == "target"
-    assert response[0]["tooltip"] == "tooltip"
-    assert response[0]["data"] == "data"
+    assert response[0].range.start.line == 0
+    assert response[0].range.start.character == 0
+    assert response[0].range.end.line == 1
+    assert response[0].range.end.character == 1
+    assert response[0].target == "target"
+    assert response[0].tooltip == "tooltip"
+    assert response[0].data == "data"
 
 
 @ConfiguredLS.decorate()
 def test_document_link_return_none(client_server):
     client, _ = client_server
     response = client.lsp.send_request(
-        DOCUMENT_LINK,
+        TEXT_DOCUMENT_DOCUMENT_LINK,
         DocumentLinkParams(
             text_document=TextDocumentIdentifier(uri="file://return.none"),
         ),
