@@ -17,8 +17,8 @@
 
 from typing import List, Optional
 
-from pygls.lsp.methods import TEXT_DOCUMENT_MONIKER
-from pygls.lsp.types import (
+from lsprotocol.types import TEXT_DOCUMENT_MONIKER
+from lsprotocol.types import (
     Moniker,
     MonikerKind,
     MonikerOptions,
@@ -74,10 +74,10 @@ def test_moniker_return_list(client_server):
 
     assert response
 
-    assert response[0]["scheme"] == "test_scheme"
-    assert response[0]["identifier"] == "test_identifier"
-    assert response[0]["unique"] == "global"
-    assert response[0]["kind"] == "local"
+    assert response[0].scheme == "test_scheme"
+    assert response[0].identifier == "test_identifier"
+    assert response[0].unique == UniquenessLevel.Global
+    assert response[0].kind == MonikerKind.Local
 
 
 @ConfiguredLS.decorate()
