@@ -36,7 +36,7 @@ class ConfiguredLS(ClientServer):
 
         @self.server.feature(TEXT_DOCUMENT_PREPARE_RENAME)
         def f(
-            params: PrepareRenameParams
+            params: PrepareRenameParams,
         ) -> Optional[Union[Range, PrepareRenameResult]]:
             return {  # type: ignore
                 "file://return.range": Range(
@@ -64,8 +64,7 @@ def test_prepare_rename_return_range(client_server):
     response = client.lsp.send_request(
         TEXT_DOCUMENT_PREPARE_RENAME,
         PrepareRenameParams(
-            text_document=TextDocumentIdentifier(
-                uri="file://return.range"),
+            text_document=TextDocumentIdentifier(uri="file://return.range"),
             position=Position(line=0, character=0),
         ),
     ).result()
@@ -84,9 +83,7 @@ def test_prepare_rename_return_prepare_rename(client_server):
     response = client.lsp.send_request(
         TEXT_DOCUMENT_PREPARE_RENAME,
         PrepareRenameParams(
-            text_document=TextDocumentIdentifier(
-                uri="file://return.prepare_rename"
-            ),
+            text_document=TextDocumentIdentifier(uri="file://return.prepare_rename"),
             position=Position(line=0, character=0),
         ),
     ).result()
