@@ -17,8 +17,8 @@
 
 from typing import List, Optional
 
-from pygls.lsp.methods import RANGE_FORMATTING
-from pygls.lsp.types import (
+from lsprotocol.types import TEXT_DOCUMENT_RANGE_FORMATTING
+from lsprotocol.types import (
     DocumentRangeFormattingOptions,
     DocumentRangeFormattingParams,
     FormattingOptions,
@@ -36,12 +36,10 @@ class ConfiguredLS(ClientServer):
         super().__init__()
 
         @self.server.feature(
-            RANGE_FORMATTING,
+            TEXT_DOCUMENT_RANGE_FORMATTING,
             DocumentRangeFormattingOptions(),
         )
-        def f(
-            params: DocumentRangeFormattingParams
-        ) -> Optional[List[TextEdit]]:
+        def f(params: DocumentRangeFormattingParams) -> Optional[List[TextEdit]]:
             if params.text_document.uri == "file://return.list":
                 return [
                     TextEdit(
@@ -68,7 +66,7 @@ def test_capabilities(client_server):
 def test_range_formatting_return_list(client_server):
     client, _ = client_server
     response = client.lsp.send_request(
-        RANGE_FORMATTING,
+        TEXT_DOCUMENT_RANGE_FORMATTING,
         DocumentRangeFormattingParams(
             text_document=TextDocumentIdentifier(uri="file://return.list"),
             range=Range(
@@ -87,18 +85,18 @@ def test_range_formatting_return_list(client_server):
 
     assert response
 
-    assert response[0]["newText"] == "text"
-    assert response[0]["range"]["start"]["line"] == 0
-    assert response[0]["range"]["start"]["character"] == 0
-    assert response[0]["range"]["end"]["line"] == 1
-    assert response[0]["range"]["end"]["character"] == 1
+    assert response[0].new_text == "text"
+    assert response[0].range.start.line == 0
+    assert response[0].range.start.character == 0
+    assert response[0].range.end.line == 1
+    assert response[0].range.end.character == 1
 
 
 @ConfiguredLS.decorate()
 def test_range_formatting_return_none(client_server):
     client, _ = client_server
     response = client.lsp.send_request(
-        RANGE_FORMATTING,
+        TEXT_DOCUMENT_RANGE_FORMATTING,
         DocumentRangeFormattingParams(
             text_document=TextDocumentIdentifier(uri="file://return.none"),
             range=Range(
